com.blockether.vis.ext.channel-tui.command-suggest

Pure slash-command discovery/filtering for the TUI prompt.

Pure slash-command discovery/filtering for the TUI prompt.
raw docstring

clamp-indexclj

(clamp-index idx total)
source

completion-textclj

(completion-text suggestion)
source

enrichclj

(enrich cmd)
source

exact-commandclj

(exact-command text commands)

Return a command only when the typed slash token exactly names it.

Return a command only when the typed slash token exactly names it.
sourceraw docstring

move-indexclj

(move-index idx delta total)
source

selected-suggestionclj

(selected-suggestion suggestions)
source

slash-queryclj

(slash-query text)

Return {:query q :args rest} when text begins with a slash command.

Return {:query q :args rest} when text begins with a slash command.
sourceraw docstring

suggestionsclj

(suggestions text commands)
(suggestions text
             commands
             {:keys [limit selected-index] :or {limit default-limit}})

Return slash-command suggestions for text from menu commands. Suggestions are fuzzy matched against id/name, label, and doc.

Return slash-command suggestions for `text` from menu `commands`.
Suggestions are fuzzy matched against id/name, label, and doc.
sourceraw docstring

usageclj

(usage cmd)

Return compact slash-command usage, including extension-provided args.

Return compact slash-command usage, including extension-provided args.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries