Pure slash-command discovery/filtering for the TUI prompt.
Pure slash-command discovery/filtering for the TUI prompt.
(exact-command text commands)Return a command only when the typed slash token exactly names it.
Return a command only when the typed slash token exactly names it.
(slash-query text)Return {:query q :args rest} when text begins with a slash command.
Return {:query q :args rest} when text begins with a slash command.
(suggestions text commands)(suggestions text
commands
{:keys [limit selected-index] :or {limit default-limit}})Return slash-command suggestions for text from menu commands.
Suggestions are fuzzy matched against id/name, label, and doc.
Return slash-command suggestions for `text` from menu `commands`. Suggestions are fuzzy matched against id/name, label, and doc.
(usage cmd)Return compact slash-command usage, including extension-provided args.
Return compact slash-command usage, including extension-provided args.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |