Lanterna adapter for internal com.blockether.vis.internal.theme tokens.
Lanterna adapter for internal `com.blockether.vis.internal.theme` tokens.
(apply-theme! theme-id)Apply registered theme id to the TUI adapter vars. Future paints use the updated Lanterna colors/widths/spacing without requiring channels to ship their own theme declaration.
Apply registered theme id to the TUI adapter vars. Future paints use the updated Lanterna colors/widths/spacing without requiring channels to ship their own theme declaration.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |